==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/uikit/UIPrinterPickerControllerDelegateAdapter.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.uikit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.corelocation.*;
/*</imports>*/

/*<javadoc>*/
/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/UIPrinterPickerControllerDelegateAdapter/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*/implements UIPrinterPickerControllerDelegate/*</implements>*/ {

    /*<ptr>*/
    /*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*//*</constructors>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @NotImplemented("printerPickerControllerParentViewController:")
    public UIViewController getParentViewController(UIPrinterPickerController printerPickerController) { return null; }
    @NotImplemented("printerPickerController:shouldShowPrinter:")
    public boolean shouldShowPrinter(UIPrinterPickerController printerPickerController, UIPrinter printer) { return false; }
    @NotImplemented("printerPickerControllerWillPresent:")
    public void willPresent(UIPrinterPickerController printerPickerController) {}
    @NotImplemented("printerPickerControllerDidPresent:")
    public void didPresent(UIPrinterPickerController printerPickerController) {}
    @NotImplemented("printerPickerControllerWillDismiss:")
    public void willDismiss(UIPrinterPickerController printerPickerController) {}
    @NotImplemented("printerPickerControllerDidDismiss:")
    public void didDismiss(UIPrinterPickerController printerPickerController) {}
    @NotImplemented("printerPickerControllerDidSelectPrinter:")
    public void didSelectPrinter(UIPrinterPickerController printerPickerController) {}
    /*</methods>*/
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/uikit/UIPrinterPickerControllerDelegateAdapter.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.uikit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.corelocation.*;
import org.robovm.apple.cloudkit.*;
import org.robovm.apple.fileprovider.*;
import org.robovm.apple.intents.*;
import org.robovm.apple.usernotifications.*;
import org.robovm.apple.linkpresentation.*;
/*</imports>*/

/*<javadoc>*/
/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/UIPrinterPickerControllerDelegateAdapter/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*/implements UIPrinterPickerControllerDelegate/*</implements>*/ {

    /*<ptr>*/
    /*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*//*</constructors>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @NotImplemented("printerPickerControllerParentViewController:")
    public UIViewController getParentViewController(UIPrinterPickerController printerPickerController) { return null; }
    @NotImplemented("printerPickerController:shouldShowPrinter:")
    public boolean shouldShowPrinter(UIPrinterPickerController printerPickerController, UIPrinter printer) { return false; }
    @NotImplemented("printerPickerControllerWillPresent:")
    public void willPresent(UIPrinterPickerController printerPickerController) {}
    @NotImplemented("printerPickerControllerDidPresent:")
    public void didPresent(UIPrinterPickerController printerPickerController) {}
    @NotImplemented("printerPickerControllerWillDismiss:")
    public void willDismiss(UIPrinterPickerController printerPickerController) {}
    @NotImplemented("printerPickerControllerDidDismiss:")
    public void didDismiss(UIPrinterPickerController printerPickerController) {}
    @NotImplemented("printerPickerControllerDidSelectPrinter:")
    public void didSelectPrinter(UIPrinterPickerController printerPickerController) {}
    /*</methods>*/
}
